From 8ffe73271e30e833e6810d8a9f0cbcdc213eed19 Mon Sep 17 00:00:00 2001
From: Joel Jakobsson <github@compiler.org>
Date: Mon, 24 Jun 2024 14:16:34 +0200
Subject: [PATCH] Add ACL (Access Control List) acronym

---
 doc/src/sgml/acronyms.sgml | 15 +++++++++++++++
 doc/src/sgml/catalogs.sgml |  6 +++---
 doc/src/sgml/ddl.sgml      |  8 ++++----
 doc/src/sgml/func.sgml     |  6 +++---
 4 files changed, 25 insertions(+), 10 deletions(-)

diff --git a/doc/src/sgml/acronyms.sgml b/doc/src/sgml/acronyms.sgml
index 6e64b190ea..93e76bf46c 100644
--- a/doc/src/sgml/acronyms.sgml
+++ b/doc/src/sgml/acronyms.sgml
@@ -9,6 +9,21 @@
 
   <variablelist>
 
+   <varlistentry>
+    <term><acronym>ACL</acronym></term>
+    <listitem>
+     <para>
+      <ulink url="https://en.wikipedia.org/wiki/Access_Control_List">Access Control List</ulink>
+     </para>
+     <para>
+      The linked page uses "permissions" while we consistently use the synonym
+      "privileges", to describe the contents of the list. For avoidance of
+      doubt and clarity, these two terms are equivalent in the
+      <productname>PostgreSQL</productname> documentation.
+     </para>
+    </listitem>
+   </varlistentry>
+
    <varlistentry>
     <term><acronym>AM</acronym></term>
     <listitem>
diff --git a/doc/src/sgml/catalogs.sgml b/doc/src/sgml/catalogs.sgml
index a63cc71efa..dd61e057b2 100644
--- a/doc/src/sgml/catalogs.sgml
+++ b/doc/src/sgml/catalogs.sgml
@@ -3349,8 +3349,8 @@ SCRAM-SHA-256$<replaceable>&lt;iteration count&gt;</replaceable>:<replaceable>&l
   </para>
 
   <para>
-   Note that when an ACL entry in another catalog is null, it is taken
-   to represent the hard-wired default privileges for its object,
+   Note that when an <acronym>ACL</acronym> entry in another catalog is null,
+   it is taken to represent the hard-wired default privileges for its object,
    <emphasis>not</emphasis> whatever might be in <structname>pg_default_acl</structname>
    at the moment.  <structname>pg_default_acl</structname> is only consulted during
    object creation.
@@ -7167,7 +7167,7 @@ SCRAM-SHA-256$<replaceable>&lt;iteration count&gt;</replaceable>:<replaceable>&l
      <listitem>
       <para>
        The referenced object (which must be a role) is mentioned in the
-       ACL (access control list, i.e., privileges list) of the
+       <acronym>ACL</acronym> of the
        dependent object.  (A <symbol>SHARED_DEPENDENCY_ACL</symbol> entry is
        not made for the owner of the object, since the owner will have
        a <symbol>SHARED_DEPENDENCY_OWNER</symbol> entry anyway.)
diff --git a/doc/src/sgml/ddl.sgml b/doc/src/sgml/ddl.sgml
index 9b71c97bdf..cc7fa8509b 100644
--- a/doc/src/sgml/ddl.sgml
+++ b/doc/src/sgml/ddl.sgml
@@ -1819,7 +1819,7 @@ ALTER TABLE products RENAME TO items;
   </indexterm>
 
   <indexterm zone="ddl-priv">
-   <primary>ACL</primary>
+   <primary><acronym>ACL</acronym></primary>
   </indexterm>
 
   <indexterm zone="ddl-priv-default">
@@ -2183,13 +2183,13 @@ REVOKE ALL ON accounts FROM PUBLIC;
   <para>
    <xref linkend="privilege-abbrevs-table"/> shows the one-letter
    abbreviations that are used for these privilege types in
-   <firstterm>ACL</firstterm> (Access Control List) values.
+   <firstterm><acronym>ACL</acronym></firstterm> values.
    You will see these letters in the output of the <xref linkend="app-psql"/>
-   commands listed below, or when looking at ACL columns of system catalogs.
+   commands listed below, or when looking at <acronym>ACL</acronym> columns of system catalogs.
   </para>
 
   <table id="privilege-abbrevs-table">
-   <title>ACL Privilege Abbreviations</title>
+   <title><acronym>ACL</acronym> Privilege Abbreviations</title>
    <tgroup cols="3">
     <colspec colname="col1" colwidth="1*"/>
     <colspec colname="col2" colwidth="1*"/>
diff --git a/doc/src/sgml/func.sgml b/doc/src/sgml/func.sgml
index 2609269610..1418c8668b 100644
--- a/doc/src/sgml/func.sgml
+++ b/doc/src/sgml/func.sgml
@@ -25276,9 +25276,9 @@ SELECT has_function_privilege('joeuser', 'myfunc(int, text)', 'execute');
         Constructs an <type>aclitem</type> array holding the default access
         privileges for an object of type <parameter>type</parameter> belonging
         to the role with OID <parameter>ownerId</parameter>.  This represents
-        the access privileges that will be assumed when an object's ACL entry
-        is null.  (The default access privileges are described in
-        <xref linkend="ddl-priv"/>.)
+        the access privileges that will be assumed when an object's
+        <acronym>ACL</acronym> entry is null. (The default access privileges
+        are described in <xref linkend="ddl-priv"/>.)
         The <parameter>type</parameter> parameter must be one of
         'c' for <literal>COLUMN</literal>,
         'r' for <literal>TABLE</literal> and table-like objects,
-- 
2.45.1

